@@ -63,6 +63,7 @@
 #include "di.h"
 #include "disystem.h"
 #include "dimath.h"
+#include "dimath_mp.h"
 #include "diinternal.h"
 #include "dizone.h"
 #include "diquota.h"
@@ -121,6 +122,8 @@ di_initialize (void)
 {
   di_data_t   *di_data;
 
+  dimath_initialize ();
+
   di_data = (di_data_t *) malloc (sizeof (di_data_t));
 
   di_data->scale_values_init = false;
@@ -181,6 +184,8 @@ di_cleanup (void *tdi_data)
   }
 
   free (di_data);
+
+  dimath_cleanup ();
 }
 
 const char *
@@ -209,6 +214,8 @@ di_process_options (void *tdi_data, int argc, const char * argv [], int offset)
     fprintf (stdout, "# MATH: GMP\n");
 #elif _use_math == DI_TOMMATH
     fprintf (stdout, "# MATH: TOMMATH\n");
+#elif _use_math == DI_MPDECIMAL
+    fprintf (stdout, "# MATH: MPDECIMAL\n");
 #else
     fprintf (stdout, "# MATH: INTERNAL: ld:%d d:%d u64:%d ll:%d l:%d\n", _siz_long_double, _siz_double, _siz_uint64_t, _siz_long, _siz_long_long);
 #endif
@@ -489,6 +496,7 @@ di_get_scaled (void *tdi_data, int infoidx,
   dinum_init (&val);
   di_calc_space (di_data, infoidx, validxA, validxB, validxC, &val);
   dval = dinum_scale (&val, &di_data->scale_values [scaleidx]);
+  dinum_clear (&val);
   return dval;
 }
 
@@ -598,7 +606,7 @@ checkFileInfo (di_data_t *di_data)
     }
 
     if (src != 0) {
-      if (errno != EACCES && errno != EPERM) {
+      if (errno != ENOENT && errno != EACCES && errno != EPERM) {
         fprintf (stderr, "stat: %s ", diopts->argv [i]);
         perror ("");
       }
@@ -751,7 +759,7 @@ getDiskStatInfo (di_data_t *di_data)
             (long) dinfo->st_dev);
       }
     } else {
-      if (errno != EACCES && errno != EPERM) {
+      if (errno != ENOENT && errno != EACCES && errno != EPERM) {
         fprintf (stderr, "stat: %s ", dinfo->strdata [DI_DISP_MOUNTPT]);
         perror ("");
       }
@@ -940,7 +948,7 @@ checkDiskInfo (di_data_t *di_data, int hasLoop)
         }
       }
 
-      /* Some systems return a -1 or -2 as an indicator.    */
+      /* Some systems return a -1 or -2 as an indicator */
       if (dinum_cmp_s (&dinfo->values [DI_SPACE_TOTAL], (di_si_t) 0) == 0 ||
           dinum_cmp_s (&dinfo->values [DI_SPACE_TOTAL], (di_si_t) -1) == 0 ||
           dinum_cmp_s (&dinfo->values [DI_SPACE_TOTAL], (di_si_t) -2L) == 0) {
@@ -1413,17 +1421,18 @@ static int
 isIgnoreFSType (const char *fstype)
 {
   /* solaris: swap */
-  /* linux: cgroup, tmpfs, squashfs, overlay */
+  /* linux: devtmpfs, cgroup, tmpfs, squashfs, overlay, efivarfs */
   if (strcmp (fstype, "rootfs") == 0 ||
       strcmp (fstype, "procfs") == 0 ||
       strcmp (fstype, "ptyfs") == 0 ||
       strcmp (fstype, "kernfs") == 0 ||
       strcmp (fstype, "devfs") == 0 ||
       strcmp (fstype, "tmpfs") == 0 ||
-      strcmp (fstype, "cgroup") == 0 ||
       strcmp (fstype, "swap") == 0 ||
+      strcmp (fstype, "cgroup") == 0 ||
       strcmp (fstype, "squashfs") == 0 ||
       strcmp (fstype, "overlay") == 0 ||
+      strcmp (fstype, "efivarfs") == 0 ||
       strcmp (fstype, "devtmpfs") == 0) {
     return true;
   }
